
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

            #pragma once

            #include <glib-object.h>

#if !defined (__PPS_PAPERS_DOCUMENT_H_INSIDE__) && !defined (PAPERS_COMPILATION)
#error "Only <papers-document.h> can be included directly."
#endif

#include "pps-macros.h"

            G_BEGIN_DECLS

/* enumerations from "pps-annotation.h" */

PPS_PUBLIC
GType pps_annotation_type_get_type (void);
#define PPS_TYPE_ANNOTATION_TYPE (pps_annotation_type_get_type())

PPS_PUBLIC
GType pps_annotation_text_icon_get_type (void);
#define PPS_TYPE_ANNOTATION_TEXT_ICON (pps_annotation_text_icon_get_type())

PPS_PUBLIC
GType pps_annotation_text_markup_type_get_type (void);
#define PPS_TYPE_ANNOTATION_TEXT_MARKUP_TYPE (pps_annotation_text_markup_type_get_type())

/* enumerations from "pps-certificate-info.h" */

PPS_PUBLIC
GType pps_certificate_status_get_type (void);
#define PPS_TYPE_CERTIFICATE_STATUS (pps_certificate_status_get_type())

/* enumerations from "pps-document-annotations.h" */

PPS_PUBLIC
GType pps_annotations_over_markup_get_type (void);
#define PPS_TYPE_ANNOTATIONS_OVER_MARKUP (pps_annotations_over_markup_get_type())

/* enumerations from "pps-document-find.h" */

PPS_PUBLIC
GType pps_find_options_get_type (void);
#define PPS_TYPE_FIND_OPTIONS (pps_find_options_get_type())

/* enumerations from "pps-document-info.h" */

PPS_PUBLIC
GType pps_document_layout_get_type (void);
#define PPS_TYPE_DOCUMENT_LAYOUT (pps_document_layout_get_type())

PPS_PUBLIC
GType pps_document_mode_get_type (void);
#define PPS_TYPE_DOCUMENT_MODE (pps_document_mode_get_type())

PPS_PUBLIC
GType pps_document_contains_js_get_type (void);
#define PPS_TYPE_DOCUMENT_CONTAINS_JS (pps_document_contains_js_get_type())

PPS_PUBLIC
GType pps_document_ui_hints_get_type (void);
#define PPS_TYPE_DOCUMENT_UI_HINTS (pps_document_ui_hints_get_type())

PPS_PUBLIC
GType pps_document_permissions_get_type (void);
#define PPS_TYPE_DOCUMENT_PERMISSIONS (pps_document_permissions_get_type())

PPS_PUBLIC
GType pps_document_info_fields_get_type (void);
#define PPS_TYPE_DOCUMENT_INFO_FIELDS (pps_document_info_fields_get_type())

/* enumerations from "pps-document.h" */

PPS_PUBLIC
GType pps_document_load_flags_get_type (void);
#define PPS_TYPE_DOCUMENT_LOAD_FLAGS (pps_document_load_flags_get_type())

PPS_PUBLIC
GType pps_document_error_get_type (void);
#define PPS_TYPE_DOCUMENT_ERROR (pps_document_error_get_type())

/* enumerations from "pps-file-exporter.h" */

PPS_PUBLIC
GType pps_file_exporter_format_get_type (void);
#define PPS_TYPE_FILE_EXPORTER_FORMAT (pps_file_exporter_format_get_type())

PPS_PUBLIC
GType pps_file_exporter_capabilities_get_type (void);
#define PPS_TYPE_FILE_EXPORTER_CAPABILITIES (pps_file_exporter_capabilities_get_type())

/* enumerations from "pps-file-helpers.h" */

PPS_PUBLIC
GType pps_compression_type_get_type (void);
#define PPS_TYPE_COMPRESSION_TYPE (pps_compression_type_get_type())

/* enumerations from "pps-form-field.h" */

PPS_PUBLIC
GType pps_form_field_text_type_get_type (void);
#define PPS_TYPE_FORM_FIELD_TEXT_TYPE (pps_form_field_text_type_get_type())

PPS_PUBLIC
GType pps_form_field_button_type_get_type (void);
#define PPS_TYPE_FORM_FIELD_BUTTON_TYPE (pps_form_field_button_type_get_type())

PPS_PUBLIC
GType pps_form_field_choice_type_get_type (void);
#define PPS_TYPE_FORM_FIELD_CHOICE_TYPE (pps_form_field_choice_type_get_type())

/* enumerations from "pps-link-action.h" */

PPS_PUBLIC
GType pps_link_action_type_get_type (void);
#define PPS_TYPE_LINK_ACTION_TYPE (pps_link_action_type_get_type())

/* enumerations from "pps-link-dest.h" */

PPS_PUBLIC
GType pps_link_dest_type_get_type (void);
#define PPS_TYPE_LINK_DEST_TYPE (pps_link_dest_type_get_type())

/* enumerations from "pps-render-context.h" */

PPS_PUBLIC
GType pps_render_annots_flags_get_type (void);
#define PPS_TYPE_RENDER_ANNOTS_FLAGS (pps_render_annots_flags_get_type())

/* enumerations from "pps-selection.h" */

PPS_PUBLIC
GType pps_selection_style_get_type (void);
#define PPS_TYPE_SELECTION_STYLE (pps_selection_style_get_type())

/* enumerations from "pps-signature.h" */

PPS_PUBLIC
GType pps_signature_status_get_type (void);
#define PPS_TYPE_SIGNATURE_STATUS (pps_signature_status_get_type())

/* enumerations from "pps-transition-effect.h" */

PPS_PUBLIC
GType pps_transition_effect_type_get_type (void);
#define PPS_TYPE_TRANSITION_EFFECT_TYPE (pps_transition_effect_type_get_type())

PPS_PUBLIC
GType pps_transition_effect_alignment_get_type (void);
#define PPS_TYPE_TRANSITION_EFFECT_ALIGNMENT (pps_transition_effect_alignment_get_type())

PPS_PUBLIC
GType pps_transition_effect_direction_get_type (void);
#define PPS_TYPE_TRANSITION_EFFECT_DIRECTION (pps_transition_effect_direction_get_type())

G_END_DECLS

/* Generated data ends here */

